@@ -922,7 +922,7 @@ void Uic::createFormImpl( const TQDomElement &e )
 		    receiver = "this";
 
 		out << indent << "TQt::Object::connect(" << sender
-		    << ", TQT_SIGNAL \"" << signal << "\", "<< receiver << ", TQT_SLOT \"" << slot << "\");" << endl;
+		    << ", TQ_SIGNAL \"" << signal << "\", "<< receiver << ", TQ_SLOT \"" << slot << "\");" << endl;
 	    }
 	} else if ( n.tagName()  == "tabstops" ) {
 	    // setup tab order
@@ -1166,7 +1166,7 @@ void Uic::createFormImpl( const TQDomElement &e )
 	    if ( *it == "init()" || *it == "destroy()" )
 		continue;
             int astart = (*it).find('(');
-            TQRegExp r( "(\\nsub\\s+" + (*it).left(astart) + "(?:\\s*#\\s*SLOT:[^\\n]+|[ \t]+)?\\n\\{)(\\s*)(\\}\\n)" );
+            TQRegExp r( "(\\nsub\\s+" + (*it).left(astart) + "(?:\\s*#\\s*TQ_SLOT:[^\\n]+|[ \t]+)?\\n\\{)(\\s*)(\\}\\n)" );
 	    r.setMinimal( true );
 	    uiPmInclude.replace( r, "\\1\n" +
 			indent + "print \"" + nameOfClass + "->" + (*it) +
